Class: Ym4r::YahooMaps::BuildingBlock::Geocoding::Result
- Inherits:
-
Struct
- Object
- Struct
- Ym4r::YahooMaps::BuildingBlock::Geocoding::Result
- Defined in:
- lib/ym4r/yahoo_maps/building_block/geocoding.rb
Overview
Contains a result match from the Yahoo! Maps geocoding service.
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
Returns the value of attribute country.
-
#latitude ⇒ Object
Returns the value of attribute latitude.
-
#longitude ⇒ Object
Returns the value of attribute longitude.
-
#precision ⇒ Object
Returns the value of attribute precision.
-
#state ⇒ Object
Returns the value of attribute state.
-
#warning ⇒ Object
Returns the value of attribute warning.
-
#zip ⇒ Object
Returns the value of attribute zip.
Instance Method Summary collapse
-
#exact_match? ⇒ Boolean
Indicates if the location passed in the request could be exactly identified.
-
#latlon ⇒ Object
Convenience method for the lazy.
-
#lonlat ⇒ Object
Convenience method for the lazy.
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def address @address end |
#city ⇒ Object
Returns the value of attribute city
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def city @city end |
#country ⇒ Object
Returns the value of attribute country
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def country @country end |
#latitude ⇒ Object
Returns the value of attribute latitude
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def latitude @latitude end |
#longitude ⇒ Object
Returns the value of attribute longitude
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def longitude @longitude end |
#precision ⇒ Object
Returns the value of attribute precision
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def precision @precision end |
#state ⇒ Object
Returns the value of attribute state
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def state @state end |
#warning ⇒ Object
Returns the value of attribute warning
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def warning @warning end |
#zip ⇒ Object
Returns the value of attribute zip
59 60 61 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 59 def zip @zip end |
Instance Method Details
#exact_match? ⇒ Boolean
Indicates if the location passed in the request could be exactly identified.
72 73 74 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 72 def exact_match? warning.nil? end |
#latlon ⇒ Object
Convenience method for the lazy.
62 63 64 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 62 def latlon [latitude,longitude] end |
#lonlat ⇒ Object
Convenience method for the lazy.
67 68 69 |
# File 'lib/ym4r/yahoo_maps/building_block/geocoding.rb', line 67 def lonlat [longitude,latitude] end |