Module: Ym4r::GoogleMaps
- Defined in:
- lib/ym4r/google_maps/api_key.rb,
lib/ym4r/google_maps/geocoding.rb
Defined Under Namespace
Modules: Geocoding
Constant Summary collapse
- API_KEY =
The key to be used by the google maps API. It is valid only for the subdiretories of the URL you applied for on this page : http://www.google.com/apis/maps/
YAML::load_file(File.dirname(__FILE__) + '/config/config.yml')